@@ -35,7 +35,7 @@ cp "$sanitizer" "$tmp_sanitizer"
 
 ar d "$tmp_sanitizer" $strip_preinit  # Intentionally not quoted
 
-"$CXX" -Wl,--whole-archive "$libfuzzer" "$tmp_sanitizer" -Wl,--no-whole-archive -lpthread -shared -o "$tmp_merged"
+"$CXX" -Wl,--whole-archive "$libfuzzer" "$tmp_sanitizer" -Wl,--no-whole-archive -lpthread -ldl -shared -o "$tmp_merged"
 
 echo "$tmp_merged"
 exit 0
